@@ -41,8 +41,8 @@ class ROCCurveReport(Report):
 
     def to_dict(self, printable=False):
         out = dict(roc_curve=self.roc_curve,
-                    auc=self.auc,
-                    labels=self.labels)
+                   auc=self.auc,
+                   labels=self.labels)
         return self._printable_dict(out, printable=printable)
 
     @classmethod
@@ -87,7 +87,7 @@ class ROCCurveReport(Report):
 
 class PrecisionRecallCurveReport(Report):
     def __init__(self, y_true, y_proba, labels=None, sample_weight=None):
-        self._labels = labels if labels is not None else unique_labels(y_true).tolist().tolist()
+        self._labels = labels if labels is not None else unique_labels(y_true).tolist()
         self._recall_precision_curve = {}
         self._average_precision = {}
         for class_index, label in enumerate(self.labels):
@@ -113,8 +113,8 @@ class PrecisionRecallCurveReport(Report):
 
     def to_dict(self, printable=False):
         out = dict(recall_precision_curve=self.recall_precision_curve,
-                    average_precision=self.average_precision,
-                    labels=self.labels)
+                   average_precision=self.average_precision,
+                   labels=self.labels)
         return self._printable_dict(out, printable=printable)
 
     @classmethod
@@ -320,9 +320,9 @@ class SklearnClassificationReport(Report):
     def to_dict(self, printable=False):
         out = dict(
             sklearn_performance_summary=self.sklearn_performance_summary,
-            roc_curve=self.roc_curve.to_dict(),
-            precision_recall_curve=self.precision_recall_curve.to_dict(),
-            calibration_curve=self.calibration_curve.to_dict(),
+            roc_curve=self.roc_curve.to_dict(printable=printable),
+            precision_recall_curve=self.precision_recall_curve.to_dict(printable=printable),
+            calibration_curve=self.calibration_curve.to_dict(printable=printable),
             labels=self.labels)
         return self._printable_dict(out, printable=printable)
 
@@ -443,8 +443,7 @@ class ConfusionMatrixReport(Report):
 
         ax.set(xticks=[-0.5] + numpy.arange(cm.shape[1]).tolist() + [cm.shape[1] - 0.5],
                yticks=[-0.5] + numpy.arange(cm.shape[0]).tolist() + [cm.shape[0] - 0.5],
-               xticklabels=[''] + labels + [''],
-               yticklabels=[''] + labels + [''],
+               xticklabels=[''] + labels + [''], yticklabels=[''] + labels + [''],
                title=title,
                ylabel='True labels',
                xlabel='Predicted labels')
@@ -691,7 +690,7 @@ class ScoringFullReport(Report):
         plt.tight_layout()
 
     def to_dict(self, printable=False):
-        metric_scores = {k: v.to_dict() for k, v in self.metric_scores.items()}
+        metric_scores = {k: v.to_dict(printable=printable) for k, v in self.metric_scores.items()}
         for v in metric_scores.values():
             v.pop('metric', None)
 
@@ -699,9 +698,11 @@ class ScoringFullReport(Report):
             metric_scores=metric_scores,
             target_metric=self.target_metric,
             separation_quality=self.separation_quality,
-            scatter=None if self.scatter is None else self.scatter.to_dict(),
-            confusion_matrix=None if self.confusion_matrix is None else self.confusion_matrix.to_dict(),
-            classification_report=None if self.classification_report is None else self.classification_report.to_dict()
+            scatter=None if self.scatter is None else self.scatter.to_dict(printable=printable),
+            confusion_matrix=None if self.confusion_matrix is None else self.confusion_matrix.to_dict(
+                printable=printable),
+            classification_report=None if self.classification_report is None else self.classification_report.to_dict(
+                printable=printable)
         )
         return self._printable_dict(out, printable=printable)
 
