@@ -1,7 +1,10 @@
-REGRESSION = 'regression'
-CLASSIFICATION = 'classification'
-
-
 class FeatureTypes():
     numerical = 'numerical'
     categorical = 'categorical'
+
+
+REGRESSION = 'regression'
+CLASSIFICATION = 'classification'
+
+NUMERICAL = FeatureTypes.numerical
+CATEGORICAL = FeatureTypes.categorical
